AllTimeSinceTodayData

Struct AllTimeSinceTodayData 

pub struct AllTimeSinceTodayData {
    pub daily_average: f64,
    pub decimal: String,
    pub digital: String,
    pub is_up_to_date: bool,
    pub percent_calculated: u8,
    pub range: AllTimeSinceTodayRange,
    pub text: String,
    pub timeout: usize,
    pub total_seconds: f64,
}

Fields

daily_average: f64

average coding activity per day as seconds for the given range of time, including Other language

decimal: String

total coding activity in decimal format

digital: String

total coding activity in digital clock format

is_up_to_date: bool

true if the stats are up to date; when false, a 202 response code is returned and stats will be refreshed soon

percent_calculated: u8

a number between 0 and 100 where 100 means the stats are up to date including Today’s time

range: AllTimeSinceTodayRange

range of time for the stats

text: String

total time logged since account created as human readable string

timeout: usize

keystroke timeout setting in minutes

total_seconds: f64

total number of seconds logged since account created