pub struct AllTimeSinceTodayData {
pub daily_average: f64,
pub decimal: String,
pub digital: String,
pub is_up_to_date: bool,
pub percent_calculated: u8,
pub range: AllTimeSinceTodayRange,
pub text: String,
pub timeout: usize,
pub total_seconds: f64,
}Fields
daily_average: f64average coding activity per day as seconds for the given range of time, including Other language
decimal: Stringtotal coding activity in decimal format
digital: Stringtotal coding activity in digital clock format
is_up_to_date: booltrue if the stats are up to date; when false, a 202 response code is returned and stats will be refreshed soon
percent_calculated: u8a number between 0 and 100 where 100 means the stats are up to date including Today’s time
range: AllTimeSinceTodayRangerange of time for the stats
text: Stringtotal time logged since account created as human readable string
timeout: usizekeystroke timeout setting in minutes
total_seconds: f64total number of seconds logged since account created